[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/1.0.0...1.0.1)

### Fixes

- Fix type hinting compatibility for 3.8. [9c2bb03](https://github.com/callowayproject/bump-my-version/commit/9c2bb03bee4c84ff97af415a47dfc57aea925c41)
    
  Replaced `list` with `List` for type hints to ensure compatibility with earlier Python versions.
